
def make_lookup():
  """
  Returns dictionary relating ID numbers to h/v/b values
  """
  d1, d2 = {}, {}

  with open(r"src\ACNH_pixel_color\res\ACNH_color_palette", "r") as f1:
    d1['column_headers'] = f1.readline().split(",")
    while s1 := f1.readline():
        vals = s1.split(",")
        if vals[3] not in d1:
          d1[vals[3]] = " ".join(vals[0:3])


  with open(r"src\ACNH_pixel_color\res\farben.txt", "r") as f2:
    while s2 := f2.readline():
      vals = s2[1:].split(",")
      d2[vals[1][:-1]] = vals[0]

  d3 = {}

  for k,v in d2.items():
    d3[k] = d1[v]

  return d3

  


from setuptools import setup, find_packages

with open("README.md", "r") as readme_file:
    readme = readme_file.read()

requirements = []

setup(
    name="ACNH_pixel_color",
    version="0.1.0",
    author="Zachary Chandler",
    author_email="zachary.c.me@gmail.com",
    description="A program to associate IDs with h/v/b values for color matching in ACNH",
    license="MIT",
    long_description=readme,
    long_description_content_type="text/markdown",
    url="https://github.com/burnish3d/ACNH_pixel_color",
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    install_requires=requirements,
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: MIT License",
    ],
)


from ACNH_pixel_color import ACNH_pixel_color as ACNH

if __name__ == "__main__":
  
  lookup = ACNH.make_lookup()
  print("Enter the lookup number of a hex code, the next line will print the values of the hue, vividness, and brightness.")
  while True:
    id = input()

    if not id.isnumeric(): break

    print(lookup.get(id,f"Values not found for {id}"))
